// Copyright 2018-2021 Cargill Incorporated
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Collections used within this crate.

mod bi_hash_map;
mod error;
mod ref_map;
#[cfg(feature = "oauth")]
mod ttl_map;

pub(crate) use bi_hash_map::BiHashMap;
pub(crate) use ref_map::RefMap;
#[cfg(feature = "oauth")]
pub(crate) use ttl_map::TtlMap;
